#!/usr/bin/env node

// adds a comment to a commit in a given repo
// comment could be any string passed via CLI arguments

import arg from 'arg'
import { GitHub } from '../'
import { Auth } from '../auth'

const args = arg({
  // repo info
  '--owner': String,
  '--repo': String,
  '--sha': String,
  '--comment': String,
})

if (!args['--owner']) {
  console.error('Missing --owner name')
  process.exit(1)
}

if (!args['--repo']) {
  console.error('Missing --repo name')
  process.exit(1)
}

if (!args['--sha']) {
  console.error('Missing --sha')
  process.exit(1)
}

if (!args['--comment']) {
  console.error('Missing --comment')
  process.exit(1)
}

async function addCommitComment() {
  const params = Auth.getFromEnvironment()
  const gh = Auth.createGithubAppClient(params)

  // by now, all fields in "args" should be valid strings
  const options: GitHub.CommitCommentOptions = {
    owner: args['--owner']!,
    repo: args['--repo']!,
    sha: args['--sha']!,
    comment: args['--comment']!,
  }
  await GitHub.addCommitComment(options, gh)
}

addCommitComment().catch((e) => {
  console.error(e.message)
  process.exit(2)
})
